bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.add_plate_axis
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaARD.add_plate_axis